@@ -285,6 +285,18 @@ class LiquidStatementEvalTestCase(unittest.TestCase):
                 expression="nil == nil",
                 expect=True,
             ),
+            Case(
+                description="nil equals null",
+                context={},
+                expression="nil == null",
+                expect=True,
+            ),
+            Case(
+                description="null equals null",
+                context={},
+                expression="null == null",
+                expect=True,
+            ),
             Case(
                 description="string contains string",
                 context={},
@@ -387,6 +399,30 @@ class LiquidStatementEvalTestCase(unittest.TestCase):
                 expression="1 == 1.0",
                 expect=True,
             ),
+            Case(
+                description="empty string equals blank",
+                context={},
+                expression="'' == blank",
+                expect=True,
+            ),
+            Case(
+                description="empty string equals empty",
+                context={},
+                expression="'' == empty",
+                expect=True,
+            ),
+            Case(
+                description="empty array equals empty",
+                context={"x": []},
+                expression="x == empty",
+                expect=True,
+            ),
+            Case(
+                description="empty array equals blank",
+                context={"x": []},
+                expression="x == blank",
+                expect=True,
+            ),
         ]
 
         self._test(test_cases, tokenize_boolean_expression, parse_boolean_expression)
